from typing import Dict, Any
from .integrations.vox_engine_api import interact
from .integrations.vox_engine_interface import VoxEngineResponse


class Client:
    """
    A client for interacting with the Minerva Vox AI service.

    Attributes:
        key (str): The Client ID associated with the API request.
        api_key (str): The Client Secret  for authentication.
    """

    def __init__(self, key: str, secret: str):
        """
        Initialize the Minerva Vox Client.

        Args:
            key (str): Client ID for authentication.
            api_key (str): Client Secret for authentication.
        """
        self.secret = secret
        self.key = key

    def interact(self, request_payload: Dict[str, Any]) -> VoxEngineResponse:
        """
        Allows passing the entire request payload as a dictionary.

        Args:
            request_payload (Dict[str, Any]): The full payload including query, plugins, etc.

        Returns:
            VoxEngineResponse: A response object containing the AI-generated message and metadata.
        """
        query = request_payload.get("query")
        thread_id = request_payload.get("threadId", None)
        plugins = request_payload.get("plugins", {})

        if not isinstance(query, str): 
            raise ValueError("query must be a string")

        return interact(query, self.key, self.secret, thread_id, plugins)


