from enum import Enum
from typing import Optional


class Status(Enum):
    """
    Enum representing the status of the response.
    """
    SUCCESS = "success"
    FAILED = "failed"  

class VoxEngineResponse:
    """
    A class representing the response from the Minerva Vox service.

    Attributes:
        status (Status): The status of the response.
        message (Optional[str]): A message from the response (only in success cases).
        error (Optional[str]): An error message (only in failure cases).
    """

    def __init__(self, status: str, message: Optional[str] = None, error: Optional[str] = None):
        self.status = Status(status)  
        self.message = message

    def __repr__(self):
        return f"VoxEngineResponse(status={self.status}, message={self.message})"

    def to_dict(self):
        return {
            "status": self.status.value,
            "message": self.message,
        }
