import json
from typing import Any, Dict, Optional
import requests
from .vox_engine_interface import VoxEngineResponse


def interact(query: str, key: str, secret: str, thread_id: Optional[str] = None, plugins: Dict[str, Any] = None) -> Dict[str, Any]:
    url = "https://vox.minervacloud.io/api/v1/vox-service/interact"
    headers = {
        "Authorization": f"Bearer {secret}",
        "Content-Type": "application/json"
    }
    payload = {
        "query": query,
        "clientId": key
    }
    if plugins:
        payload["plugins"] = plugins  
    if thread_id:
        payload["threadId"] = thread_id  

    try:
        response = requests.post(url, json=payload, headers=headers)
        response.raise_for_status()

        return response.json()

    except requests.exceptions.HTTPError as e:
        return {"status": "failed", "error": f"HTTP error occurred: {str(e)}"}

    except requests.exceptions.JSONDecodeError:
        return {"status": "failed", "error": f"Invalid JSON response: {response.text}"}

    except Exception as e:
        return {"status": "failed", "error": f"Failed to generate response: {str(e)}"}
